@@ -228,7 +228,7 @@ impl<'a> TryFrom<(FrequencyUnify<'a>, ScheduleIteratorTimeZone)> for FrequencyIn
                     return Err(FrequencyAnalyzeError::DisInitTime);
                 }
 
-                let seconds_state: SecondsState = (get_timestamp()..).step_by(seconds as usize);
+                let seconds_state: SecondsState = (timestamp()..).step_by(seconds as usize);
                 FrequencyInner::SecondsCountDown(1, seconds_state)
             }
             FrequencyUnify::FrequencySeconds(FrequencySeconds::Repeated(seconds)) => {
@@ -236,7 +236,7 @@ impl<'a> TryFrom<(FrequencyUnify<'a>, ScheduleIteratorTimeZone)> for FrequencyIn
                     return Err(FrequencyAnalyzeError::DisInitTime);
                 }
 
-                let seconds_state: SecondsState = (get_timestamp()..).step_by(seconds as usize);
+                let seconds_state: SecondsState = (timestamp()..).step_by(seconds as usize);
 
                 FrequencyInner::SecondsRepeated(seconds_state)
             }
@@ -245,7 +245,7 @@ impl<'a> TryFrom<(FrequencyUnify<'a>, ScheduleIteratorTimeZone)> for FrequencyIn
                     return Err(FrequencyAnalyzeError::DisInitTime);
                 }
 
-                let seconds_state: SecondsState = (get_timestamp()..).step_by(seconds as usize);
+                let seconds_state: SecondsState = (timestamp()..).step_by(seconds as usize);
                 FrequencyInner::SecondsCountDown(count_down, seconds_state)
             }
         };
@@ -513,7 +513,7 @@ impl TaskContext {
                 .send(TimerEvent::FinishTask(FinishTaskBody {
                     task_id: self.task_id,
                     record_id: self.record_id,
-                    finish_time: get_timestamp(),
+                    finish_time: timestamp(),
                     finish_output,
                 }))
                 .await
@@ -570,7 +570,7 @@ impl<F: Fn() -> U + 'static + Send, U: Future + 'static + Send> Routine for Asyn
 
     #[inline(always)]
     fn spawn_by_tokio(&self, task_context: TaskContext) -> Self::TokioHandle {
-        let user_future = (&self.0)();
+        let user_future = self.0();
 
         async_spawn_by_tokio({
             let task_id = task_context.task_id;
@@ -589,7 +589,7 @@ impl<F: Fn() -> U + 'static + Send, U: Future + 'static + Send> Routine for Asyn
 
     #[inline(always)]
     fn spawn_by_smol(&self, task_context: TaskContext) -> Self::SmolHandle {
-        let user_future = (&self.0)();
+        let user_future = self.0();
 
         async_spawn_by_smol({
             let task_id = task_context.task_id;
@@ -623,7 +623,7 @@ impl<F: Fn() + 'static + Send + Clone> Routine for SyncFn<F> {
 
     #[inline(always)]
     fn spawn_by_tokio(&self, task_context: TaskContext) -> Self::TokioHandle {
-        let fn_handle = unblock_spawn_by_tokio((&self.0).clone());
+        let fn_handle = unblock_spawn_by_tokio(self.0.clone());
 
         let task_id = task_context.task_id;
         let record_id = task_context.record_id;
@@ -645,7 +645,7 @@ impl<F: Fn() + 'static + Send + Clone> Routine for SyncFn<F> {
 
     #[inline(always)]
     fn spawn_by_smol(&self, task_context: TaskContext) -> Self::SmolHandle {
-        let fn_handle = unblock_spawn_by_smol((&self.0).clone());
+        let fn_handle = unblock_spawn_by_smol(self.0.clone());
 
         let task_id = task_context.task_id;
         let record_id = task_context.record_id;
@@ -1008,7 +1008,7 @@ impl<'a> TaskBuilder<'a> {
 
     pub fn set_frequency_once_by_timestamp_seconds(&mut self, timestamp_seconds: u64) -> &mut Self {
         let duration = timestamp_seconds
-            .checked_sub(get_timestamp())
+            .checked_sub(timestamp())
             .unwrap_or(ONE_SECOND);
 
         self.frequency = FrequencyUnify::FrequencySeconds(FrequencySeconds::Once(duration));
@@ -1148,7 +1148,7 @@ mod tests {
             .map(|i| {
                 debug_assert_eq!(
                     task.get_next_exec_timestamp().unwrap(),
-                    get_timestamp() + (init_seconds * (i - 1))
+                    timestamp() + (init_seconds * (i - 1))
                 );
             })
             .for_each(drop);
@@ -1180,7 +1180,7 @@ mod tests {
             .map(|i| {
                 debug_assert_eq!(
                     task.get_next_exec_timestamp().unwrap(),
-                    get_timestamp() + (init_minutes * (i - 1) * ONE_MINUTE)
+                    timestamp() + (init_minutes * (i - 1) * ONE_MINUTE)
                 );
             })
             .for_each(drop);
@@ -1201,7 +1201,7 @@ mod tests {
             .map(|i| {
                 debug_assert_eq!(
                     task.get_next_exec_timestamp().unwrap(),
-                    get_timestamp() + (init_hours * (i - 1) * ONE_HOUR)
+                    timestamp() + (init_hours * (i - 1) * ONE_HOUR)
                 );
             })
             .for_each(drop);
@@ -1222,7 +1222,7 @@ mod tests {
             .map(|i| {
                 debug_assert_eq!(
                     task.get_next_exec_timestamp().unwrap(),
-                    get_timestamp() + (init_days * (i - 1) * ONE_DAY)
+                    timestamp() + (init_days * (i - 1) * ONE_DAY)
                 );
             })
             .for_each(drop);
