@@ -2,11 +2,11 @@
 //! It is the core of the entire cycle scheduling task.
 use crate::prelude::*;
 
-use crate::entity::get_timestamp;
+use crate::entity::timestamp;
 use crate::entity::RuntimeKind;
 
 use std::mem::replace;
-use std::sync::atomic::Ordering::{Acquire, Relaxed, Release};
+use std::sync::atomic::Ordering::{Acquire, Release};
 use std::time::Duration;
 use std::time::Instant;
 
@@ -15,10 +15,12 @@ use smol::Timer as smolTimer;
 pub(crate) const DEFAULT_TIMER_SLOT_COUNT: u64 = 3600;
 
 /// The clock of timer core.
+#[derive(Debug)]
 struct Clock {
     inner: ClockInner,
 }
 
+#[derive(Debug)]
 enum ClockInner {
     Sc(SmolClock),
 
@@ -52,7 +54,7 @@ impl Clock {
             ClockInner::Sc(ref mut smol_clock) => smol_clock.tick().await,
 
             ClockInner::Tc(ref mut tokio_clock) => tokio_clock.tick().await,
-        }
+        };
     }
 }
 use tokio::time::{self, interval_at, Interval};
@@ -142,14 +144,15 @@ pub enum TimerEvent {
     /// Take the initiative to perform once Task.
     AdvanceTask(u64),
 }
-#[derive(Clone, Debug)]
+#[derive(Debug)]
 /// delay-timer internal timer wheel core.
 pub struct Timer {
     /// Event sender that provides events to `EventHandle` processing.
-    pub(crate) timer_event_sender: TimerEventSender,
+    timer_event_sender: TimerEventSender,
     #[allow(dead_code)]
     status_report_sender: Option<AsyncSender<i32>>,
-    pub(crate) shared_header: SharedHeader,
+    shared_header: SharedHeader,
+    clock: Clock,
 }
 
 // In any case, the task is not executed in the Scheduler,
@@ -158,10 +161,14 @@ pub struct Timer {
 impl Timer {
     /// Initialize a timer wheel core.
     pub fn new(timer_event_sender: TimerEventSender, shared_header: SharedHeader) -> Self {
+        let runtime_kind = shared_header.runtime_instance.kind;
+        let clock = Clock::new(runtime_kind);
+
         Timer {
             timer_event_sender,
             status_report_sender: None,
             shared_header,
+            clock,
         }
     }
 
@@ -173,23 +180,22 @@ impl Timer {
     /// Offset the current slot by one when reading it,
     /// so event_handle can be easily inserted into subsequent slots.
     pub(crate) fn next_position(&mut self) -> u64 {
-        self.shared_header
-            .second_hand
-            .fetch_update(Release, Relaxed, |x| {
-                Some((x + 1) % DEFAULT_TIMER_SLOT_COUNT)
-            })
-            .unwrap_or_else(|e| e)
+        self.shared_header.second_hand.next().unwrap_or_else(|e| e)
+    }
+
+    /// Time goes on, the clock ticks.
+    pub(crate) async fn lapse(&mut self) {
+        self.clock.tick().await;
+        self.next_position();
     }
 
     /// Return a future can pool it for Schedule all cycles task.
     pub(crate) async fn async_schedule(&mut self) {
-        // if that overtime , i run it not block
-        let mut second_hand;
-        let mut next_second_hand;
-        let mut timestamp;
+        // if that overtime , run it not block
 
-        let runtime_kind = self.shared_header.runtime_instance.kind;
-        let mut clock = Clock::new(runtime_kind);
+        let mut second_hand = self.second_hand();
+        let mut next_second_hand = second_hand + 1;
+        let mut current_timestamp = timestamp();
 
         loop {
             //TODO: replenish ending single, for stop current jod and thread.
@@ -197,9 +203,9 @@ impl Timer {
                 return;
             }
 
-            second_hand = self.next_position();
-            timestamp = get_timestamp();
-            self.shared_header.global_time.store(timestamp, Release);
+            self.shared_header
+                .global_time
+                .store(current_timestamp, Release);
             let task_ids;
 
             {
@@ -217,7 +223,12 @@ impl Timer {
                 }
             }
 
-            trace!("timestamp: {}, task_ids: {:?}", timestamp, task_ids);
+            trace!(
+                "second_hand: {}, timestamp: {}, task_ids: {:?}",
+                second_hand,
+                current_timestamp,
+                task_ids
+            );
 
             // Centralize task processing to avoid duplicate lock requests and releases.
             // FIXME: https://github.com/BinChengZhao/delay-timer/issues/29
@@ -234,8 +245,7 @@ impl Timer {
                 }
 
                 if let Some(task) = task_option {
-                    next_second_hand = (second_hand + 1) % DEFAULT_TIMER_SLOT_COUNT;
-                    self.maintain_task(task, timestamp, next_second_hand)
+                    self.maintain_task(task, current_timestamp, next_second_hand)
                         .await
                         .map_err(|e| error!("{}", e))
                         .ok();
@@ -250,10 +260,20 @@ impl Timer {
                 }
             }
 
-            clock.tick().await;
+            self.lapse().await;
+
+            second_hand = self.second_hand();
+            next_second_hand = (second_hand + 1) % DEFAULT_TIMER_SLOT_COUNT;
+            current_timestamp = timestamp();
         }
     }
 
+    /// Access to the second-hand
+    pub(crate) fn second_hand(&self) -> u64 {
+        self.shared_header.second_hand.current_second_hand()
+    }
+
+    /// Send timer-event to event-handle.
     pub(crate) async fn send_timer_event(
         &mut self,
         task_id: u64,
@@ -347,6 +367,11 @@ impl Timer {
             .get_next_exec_timestamp()
             .ok_or_else(|| anyhow!("can't get_next_exec_timestamp in task :{}", task.task_id))?;
 
+        // cylinder_line = 24
+        // slot_seed = 60
+        // when-init: slot_seed+=1 == 61
+        // when-on-slot61-exec: (task_excute_timestamp - timestamp + next_second_hand) % slot_seed == 61
+
         // Time difference + next second hand % DEFAULT_TIMER_SLOT_COUNT
         let step = task_excute_timestamp.checked_sub(timestamp).unwrap_or(1) + next_second_hand;
         let cylinder_line = step / DEFAULT_TIMER_SLOT_COUNT;
@@ -401,8 +426,8 @@ impl Timer {
 
 mod tests {
 
-    #[test]
-    fn test_next_position() {
+    #[tokio::test]
+    async fn test_next_position() {
         use super::{SharedHeader, Timer, TimerEvent};
         use smol::channel::unbounded;
         use std::sync::atomic::Ordering;
@@ -415,6 +440,7 @@ mod tests {
         timer
             .shared_header
             .second_hand
+            .inner
             .store(3599, Ordering::SeqCst);
         assert_eq!(timer.next_position(), 3599);
         assert_eq!(timer.next_position(), 0);
